from typing import TYPE_CHECKING, Any

from sqlalchemy import Boolean, Column, ForeignKey, String
from sqlalchemy.dialects.mysql import TEXT
from sqlalchemy.orm import relationship

from app.db.base_class import Base

if TYPE_CHECKING:
    from .bucket_permission import BucketPermission
    from .user import User


class Bucket(Base):
    """
    Database model for a bucket.
    """

    __tablename__: str = "bucket"
    name: str = Column(String(63), primary_key=True, index=True, unique=True)
    description: str = Column(TEXT, nullable=False)
    public: bool = Column(Boolean(), default=False, server_default="0", nullable=False)
    owner_id: str = Column(ForeignKey("user.uid"), nullable=True)
    owner: "User" = relationship("User", back_populates="buckets")
    permissions: list["BucketPermission"] = relationship(
        "BucketPermission",
        back_populates="bucket",
        cascade="all, delete",
        passive_deletes=True,
    )

    __mapper_args__ = {"eager_defaults": True}

    def __eq__(self, other: Any) -> bool:
        return self.name == other.name if isinstance(other, Bucket) else False

    def __repr__(self) -> str:
        return f"'Bucket(name={self.name}', owner='{self.owner_id}')"
