from typing import TYPE_CHECKING, Any

from sqlalchemy import Column, String
from sqlalchemy.orm import relationship

from app.db.base_class import Base

if TYPE_CHECKING:
    from .bucket import Bucket
    from .bucket_permission import BucketPermission


class User(Base):
    """
    Database model for a user.
    """

    __tablename__: str = "user"
    uid: str = Column(String(64), primary_key=True, index=True, unique=True)
    display_name: str = Column(String(256), nullable=False)
    buckets: list["Bucket"] = relationship("Bucket", back_populates="owner")
    permissions: list["BucketPermission"] = relationship("BucketPermission", back_populates="grantee")

    def __eq__(self, other: Any) -> bool:
        return self.uid == other.uid if isinstance(other, User) else False

    def __repr__(self) -> str:
        return f"'User(uid={self.uid}', display_name='{self.display_name}')"
