from pydantic import BaseModel, Field


class User(BaseModel):
    """
    Schema for a user.
    """

    uid: str = Field(
        ...,
        description="ID of the user",
        example="28c5353b8bb34984a8bd4169ba94c606",
        max_length=64,
    )
    display_name: str = Field(
        ...,
        description="Full Name of the user",
        example="Bilbo Baggins",
        max_length=256,
    )

    class Config:
        orm_mode = True


class S3Key(BaseModel):
    """
    Schema for a S3 key associated with a user.
    """

    user: str = Field(..., description="UID of the user of that access key", example="28c5353b8bb34984a8bd4169ba94c606")
    access_key: str = Field(..., description="ID of the S3 access key", example="CRJ6B037V2ZT4U3W17VC")
    secret_key: str = Field(
        ...,
        description="Secret of the S3 access key",
        example="2F5uNTI1qvt4oAroXV0wWct8rWclL2QvFXKqSqjS",
    )
