import random
import string
from datetime import datetime
from typing import Any


def random_lower_string(length: int = 32) -> str:
    """
    Creates a random string with arbitrary length.

    Parameters
    ----------
    length : int, default 32
        Length for the random string.

    Returns
    -------
    string : str
        Random string.
    """
    return "".join(random.choices(string.ascii_lowercase, k=length))


def random_ipv4_string() -> str:
    """
    Creates a random IPv4 address.

    Returns
    -------
    string : str
        Random IPv4 address.
    """
    return ".".join(str(random.randint(0, 255)) for _ in range(4))


def json_datetime_converter(obj: Any) -> str | None:
    """
    helper function for the json converter to covert the object into a string format if it is a datetime object.\n
    Parse a datetime object into the format YYYY-MM-DDTHH:MM:SS, e.g. 2022-01-01T00:00:00

    Parameters
    ----------
    obj : Any
        Object to try convert as a datetime object.

    Returns
    -------
    time : str | None
        The str representation of a datetime object, None otherwise
    """
    if isinstance(obj, datetime):
        return obj.strftime("%Y-%m-%dT%H:%M:%S")
    return None
